service property
S
service
final
Agent that handles retrieve of pure raw information from the API or Firebase...
Implementation
final S service;
Agent that handles retrieve of pure raw information from the API or Firebase...
final S service;